==> alliance-5.0-20020701.tar.gz: alliance-5.0/xfsm/src/XMX_icon.c <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   XFSM                            |
|                                                             |
| File    :                   Icon.c                          |
|                                                             |
| Authors :              Jacomme Ludovic                      |
|                                                             |
| Date    :                   04.12.96                        |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# include <stdio.h>
# include <Xm/Xm.h>
# include <Xm/PushB.h>
# include <Xm/Form.h>
# include <Xm/Frame.h>
 
# include "mut.h"
# include "aut.h"
# include "abl.h"
# include "bdd.h"
# include "fsm.h"
# include "XSB.h"
# include "XTB.h"
# include "XMX.h"

# include "XMX_icon.h"

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/

  static char IconBits[] = 

  {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x0f, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x60, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10,
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x40, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x16, 0x40, 0x03, 0x00, 0x00, 0x00, 0x00, 0x11, 0x40, 0x04, 0x00, 0x00,
  0x00, 0x80, 0x60, 0x30, 0x08, 0x00, 0x00, 0x00, 0x40, 0x80, 0x0f, 0x10,
  0x00, 0x00, 0x00, 0x20, 0x00, 0x02, 0x20, 0x00, 0x00, 0x00, 0x20, 0x00,
  0x07, 0x20, 0x00, 0x00, 0x00, 0x10, 0x80, 0x0f, 0x40, 0x00, 0x00, 0x00,
  0x10, 0x40, 0x12, 0x40, 0x00, 0x00, 0x00, 0x10, 0x00, 0x02, 0x40, 0x00,
  0x00, 0x00, 0x08, 0x00, 0x02, 0x80, 0x00, 0x00, 0x00, 0x08, 0x00, 0x02,
  0x80, 0x00, 0x00, 0x00, 0x08, 0x00, 0x02, 0x80, 0x00, 0x00, 0x00, 0x08,
  0x00, 0x02, 0x80, 0x00, 0x00, 0x00, 0x08, 0x00, 0x02, 0x80, 0x00, 0x00,
  0x00, 0x04, 0x00, 0x02, 0x00, 0x01, 0x00, 0x00, 0x04, 0x00, 0x01, 0x00,
  0x01, 0x00, 0x00, 0x04, 0x00, 0x01, 0x00, 0x01, 0x00, 0x00, 0x04, 0x00,
  0x01, 0x00, 0x01, 0x00, 0x80, 0x24, 0x80, 0x00, 0x20, 0x09, 0x00, 0x00,
  0x1f, 0x80, 0x00, 0xc0, 0x07, 0x00, 0x00, 0x0e, 0x40, 0x00, 0x80, 0x03,
  0x00, 0x00, 0x04, 0x20, 0x00, 0x00, 0x01, 0x00, 0x00, 0x1f, 0x18, 0x00,
  0xc0, 0x07, 0x00, 0xc0, 0x60, 0x07, 0x00, 0x30, 0x18, 0x00, 0x20, 0x80,
  0x00, 0x00, 0x08, 0x20, 0x00, 0x20, 0x80, 0x10, 0x40, 0x08, 0x20, 0x00,
  0x10, 0x00, 0x09, 0x80, 0x04, 0x40, 0x00, 0x10, 0x00, 0x0d, 0x80, 0x05,
  0x40, 0x00, 0x10, 0x00, 0xff, 0xff, 0x07, 0x40, 0x00, 0x10, 0x00, 0x0d,
  0x80, 0x05, 0x40, 0x00, 0x10, 0x00, 0x09, 0x80, 0x04, 0x40, 0x00, 0x20,
  0x80, 0x10, 0x40, 0x08, 0x20, 0x00, 0x20, 0x80, 0x00, 0x00, 0x08, 0x20,
  0x00, 0xc0, 0x60, 0x00, 0x00, 0x30, 0x18, 0x00, 0x00, 0x1f, 0x00, 0x00,
  0xc0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, };

/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                    XfsmInitializeIcon                      |
|                                                             |
\------------------------------------------------------------*/

void XfsmInitializeIcon()

{
  autbegin();

  XfsmSetIcon( XfsmTopLevel, 
                IconBits, IconWidth, IconHeight );

  autend();
}

==> alliance-5.0-20110203.tar.gz: alliance-5.0/xfsm/src/XMX_icon.c <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   XFSM                            |
|                                                             |
| File    :                   Icon.c                          |
|                                                             |
| Authors :              Jacomme Ludovic                      |
|                                                             |
| Date    :                   04.12.96                        |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# include <stdio.h>
# include <Xm/Xm.h>
# include <Xm/PushB.h>
# include <Xm/Form.h>
# include <Xm/Frame.h>
 
# include "mut.h"
# include "aut.h"
# include "abl.h"
# include "bdd.h"
# include "fsm.h"
# include "XSB.h"
# include "XTB.h"
# include "XMX.h"

# include "XMX_icon.h"

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/

  static char IconBits[] = 

  {
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x0f, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x60, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10,
  0x40, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x40, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x16, 0x40, 0x03, 0x00, 0x00, 0x00, 0x00, 0x11, 0x40, 0x04, 0x00, 0x00,
  0x00, 0x80, 0x60, 0x30, 0x08, 0x00, 0x00, 0x00, 0x40, 0x80, 0x0f, 0x10,
  0x00, 0x00, 0x00, 0x20, 0x00, 0x02, 0x20, 0x00, 0x00, 0x00, 0x20, 0x00,
  0x07, 0x20, 0x00, 0x00, 0x00, 0x10, 0x80, 0x0f, 0x40, 0x00, 0x00, 0x00,
  0x10, 0x40, 0x12, 0x40, 0x00, 0x00, 0x00, 0x10, 0x00, 0x02, 0x40, 0x00,
  0x00, 0x00, 0x08, 0x00, 0x02, 0x80, 0x00, 0x00, 0x00, 0x08, 0x00, 0x02,
  0x80, 0x00, 0x00, 0x00, 0x08, 0x00, 0x02, 0x80, 0x00, 0x00, 0x00, 0x08,
  0x00, 0x02, 0x80, 0x00, 0x00, 0x00, 0x08, 0x00, 0x02, 0x80, 0x00, 0x00,
  0x00, 0x04, 0x00, 0x02, 0x00, 0x01, 0x00, 0x00, 0x04, 0x00, 0x01, 0x00,
  0x01, 0x00, 0x00, 0x04, 0x00, 0x01, 0x00, 0x01, 0x00, 0x00, 0x04, 0x00,
  0x01, 0x00, 0x01, 0x00, 0x80, 0x24, 0x80, 0x00, 0x20, 0x09, 0x00, 0x00,
  0x1f, 0x80, 0x00, 0xc0, 0x07, 0x00, 0x00, 0x0e, 0x40, 0x00, 0x80, 0x03,
  0x00, 0x00, 0x04, 0x20, 0x00, 0x00, 0x01, 0x00, 0x00, 0x1f, 0x18, 0x00,
  0xc0, 0x07, 0x00, 0xc0, 0x60, 0x07, 0x00, 0x30, 0x18, 0x00, 0x20, 0x80,
  0x00, 0x00, 0x08, 0x20, 0x00, 0x20, 0x80, 0x10, 0x40, 0x08, 0x20, 0x00,
  0x10, 0x00, 0x09, 0x80, 0x04, 0x40, 0x00, 0x10, 0x00, 0x0d, 0x80, 0x05,
  0x40, 0x00, 0x10, 0x00, 0xff, 0xff, 0x07, 0x40, 0x00, 0x10, 0x00, 0x0d,
  0x80, 0x05, 0x40, 0x00, 0x10, 0x00, 0x09, 0x80, 0x04, 0x40, 0x00, 0x20,
  0x80, 0x10, 0x40, 0x08, 0x20, 0x00, 0x20, 0x80, 0x00, 0x00, 0x08, 0x20,
  0x00, 0xc0, 0x60, 0x00, 0x00, 0x30, 0x18, 0x00, 0x00, 0x1f, 0x00, 0x00,
  0xc0, 0x07, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, };

/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                    XfsmInitializeIcon                      |
|                                                             |
\------------------------------------------------------------*/

void XfsmInitializeIcon()

{
  autbegin();

  XfsmSetIcon( XfsmTopLevel, 
                IconBits, IconWidth, IconHeight );

  autend();
}
